#
# spec file for package python-s3transfer
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-s3transfer
Version:        0.2.1
Release:        lp151.2.3.1
Summary:        Python S3 transfer manager
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/boto/s3transfer
Source0:        https://files.pythonhosted.org/packages/source/s/s3transfer/s3transfer-%{version}.tar.gz
Patch0:         hide_py_pckgmgmt.patch
Patch1:         no-bundled-packages.patch
BuildRequires:  %{python_module botocore >= 1.12.36}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module urllib3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-futures >= 2.2.0
Requires:       python-botocore <= 2.0.0
Requires:       python-botocore >= 1.12.36
Requires:       python-requests
Requires:       python-urllib3
BuildArch:      noarch
%ifpython2
Requires:       python-futures <= 4.0.0
Requires:       python-futures >= 2.2.0
%endif
%python_subpackages

%description
A transfer manager for Amazon Web Services S3

%prep
%setup -q -n s3transfer-%{version}
%patch0 -p1
%patch1 -p1
# remove integration tests that need running s3 :)
rm -rf tests/integration

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# on 32bit the tests fail on OOM and various other funny things
%ifarch x86_64
%python_expand nosetests-%{$python_bin_suffix}
%endif

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/s3transfer/
%{python_sitelib}/s3transfer-%{version}-py*.egg-info

%changelog
* Thu Aug 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1146854)
* Wed Jun 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.1
  * enhancment:ProcessPool: Adds user agent suffix.
* Wed Feb 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.0
  * feature:``ProcessPoolDownloader``: Add ``ProcessPoolDownloader`` class
    to speed up download throughput by using processes instead of threads.
- Drop obsolete patch
  + system-requests.patch
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
  + no-bundled-packages.patch
- Update Requires in spec file from setup.py
* Wed May  9 2018 tchvatal@suse.com
- Avoid running tests on 32bit as they fail there on oom
* Tue May  8 2018 tchvatal@suse.com
- Make sure to really not use any damn bundles:
  * no-bundled-packages.patch
  * Never rely on some bundled package version just use system libs
- Enable testsuite and make it pass thanks to above patch
* Thu Apr 19 2018 mimi.vx@gmail.com
- update to 0.1.13
- add system-requests.patch - use system python-requests
  * Plumb ``RequestPayer` argument to the ``CompleteMultipartUpload` operation
  * enhancement:max_bandwidth: Add ability to set maximum bandwidth consumption
  for streaming of S3 uploads and downloads
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 0.1.11:
  + Properly handle unicode exceptions in the context manager
* Thu May 11 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update source URL.
* Thu Jan 19 2017 dmueller@suse.com
- use pypi.io
* Wed Jan 18 2017 astieger@suse.com
- update to 0.1.10:
  * feature: TransferManager: Expose ability to use own executor
    class for TransferManager
  * fix factory submission (validate source)
* Wed Oct 26 2016 rjschwei@suse.com
- Update to version 0.1.9 (bsc#1007084)
  + Forward port hide_py_pckgmgmt.patch
  + No changelog entry for 0.1.9
- From 0.1.8
  + feature:download: Support downloading to FIFOs.
- From 0.1.7
  + bugfix:TransferManager: Fix memory leak when using same client to create
    multiple TransferManagers
- From 0.1.6
  + bugfix:download: Fix issue where S3 Object was not downloaded to disk
    when empty
- From 0.1.5
  + bugfix:Cntrl-C: Fix issue of hangs when Cntrl-C happens for many queued
    transfers
  + feature:cancel: Expose messages for cancels
- from 0.1.4
  + feature:chunksize: Automatically adjust the chunksize if it doesn't meet
    S3s requirements.
  + bugfix:Download: Add support for downloading to special UNIX file by name
- From 0.1.3
  + feature:delete: Add a .delete() method to the transfer manager.
  + bugfix:seekable upload: Fix issue where seeked position of seekable
    file for a nonmultipart upload was not being taken into account.
- From 0.1.2
  + bugfix:download: Patch memory leak related to unnecessarily holding
    onto futures for downloads.
- From 0.1.1
  + bugfix:deadlock: Fix deadlock issue described here:
    https://bugs.python.org/issue20319 with using concurrent.futures.wait
- From 0.1.0
  + feature:copy: Add support for managed copies.
  + feature:download: Add support for downloading to a filename, seekable
    file-like object, and nonseekable file-like object.
  + feature:general: Add TransferManager class. All public functionality
    for s3transfer is exposed through this class.
  + feature:subscribers: Add subscriber interface. Currently supports
    on_queued, on_progress, and on_done status changes.
  + feature:upload: Add support for uploading a filename, seekable file-like
    object, and nonseekable file-like object.
* Mon Apr 18 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#320748, bsc#974993, bsc#975949)
* Tue Apr 12 2016 rjschwei@suse.com
- Set the proper target directory for copying the license file
  + Fixes build issue on SLE 11
* Mon Apr 11 2016 rjschwei@suse.com
- Initial build
  + Version 0.0.1
